"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../src/utils");
describe('Utils', () => {
    describe('priceFormatter', () => {
        const baseTestCases = [
            {
                description: 'format price with decimals',
                priceSmallestUnit: 799,
                priceMainUnit: 7.99,
                fromCurrency: { symbol: '$', decimals: 2 },
                expected: '$ 7.99',
            },
            {
                description: 'format integer price by removing trailing zeros',
                priceSmallestUnit: 800,
                priceMainUnit: 8.0,
                fromCurrency: { symbol: '$', decimals: 2 },
                expected: '$ 8',
            },
            {
                description: 'format price with different currency symbol',
                priceSmallestUnit: 799,
                priceMainUnit: 7.99,
                fromCurrency: { symbol: '€', decimals: 2 },
                expected: '€ 7.99',
            },
            {
                description: 'format price with different decimals',
                priceSmallestUnit: 12345,
                priceMainUnit: 12.345,
                fromCurrency: { symbol: '$', decimals: 3 },
                expected: '$ 12.345',
            },
            {
                description: 'format price with empty string as symbol',
                priceSmallestUnit: 1234,
                priceMainUnit: 12.34,
                fromCurrency: { symbol: '', decimals: 2 },
                expected: ' 12.34',
            },
            {
                description: 'format price with empty string as symbol and a negative',
                priceSmallestUnit: 1234,
                priceMainUnit: 12.34,
                fromCurrency: { symbol: '', decimals: 2 },
                negative: true,
                expected: '- 12.34',
            },
            // Edge cases
            {
                description: 'format zero price',
                priceSmallestUnit: 0,
                priceMainUnit: 0.0,
                fromCurrency: { symbol: '$', decimals: 2 },
                expected: '$ 0',
            },
            {
                description: 'format price with no decimals',
                priceSmallestUnit: 1234,
                priceMainUnit: 1234,
                fromCurrency: { symbol: '$', decimals: 0 },
                expected: '$ 1,234',
            },
            {
                description: 'format price with a negative',
                priceSmallestUnit: 1234,
                priceMainUnit: 12.34,
                fromCurrency: { symbol: '$', decimals: 2 },
                negative: true,
                expected: '-$ 12.34',
            },
        ];
        describe('when price is in smallest unit (without conversion)', () => {
            baseTestCases.forEach(({ description, priceSmallestUnit, fromCurrency, negative, expected, }) => {
                it(`should ${description} from smallest unit`, () => {
                    const formattedPrice = (0, utils_1.priceFormatter)({
                        price: priceSmallestUnit,
                        fromCurrency,
                        fromSmallestUnit: true,
                        negative,
                    });
                    expect(formattedPrice).toBe(expected);
                });
            });
        });
        describe('when price is in main unit (without conversion)', () => {
            baseTestCases.forEach(({ description, priceMainUnit, fromCurrency, negative, expected }) => {
                it(`should ${description} from main unit`, () => {
                    const formattedPrice = (0, utils_1.priceFormatter)({
                        price: priceMainUnit,
                        fromCurrency,
                        negative,
                    });
                    expect(formattedPrice).toBe(expected);
                });
            });
        });
        describe('when converting to a destination currency', () => {
            const conversionTestCases = [
                {
                    description: 'convert price from smallest unit to target currency (e.g. USD to EUR)',
                    priceSmallestUnit: 10000, // represents $100.00
                    priceMainUnit: 100,
                    fromCurrency: { symbol: '$', decimals: 2 },
                    toCurrency: { symbol: '€', decimals: 2, mid: 0.85 },
                    expected: '€ 85', // 100 * 0.85 = 85
                },
                {
                    description: 'convert price from main unit to target currency with decimals (e.g. USD to GBP)',
                    priceSmallestUnit: 799,
                    priceMainUnit: 7.99,
                    fromCurrency: { symbol: '$', decimals: 2 },
                    toCurrency: { symbol: '£', decimals: 2, mid: 0.75 },
                    expected: '£ 5.99', // 7.99 * 0.75 ≈ 5.9925 => formatted as 5.99
                },
            ];
            describe('when price is in smallest unit', () => {
                conversionTestCases.forEach(({ description, priceSmallestUnit, fromCurrency, toCurrency, expected, }) => {
                    it(`should ${description} from smallest unit`, () => {
                        const formattedPrice = (0, utils_1.priceFormatter)({
                            price: priceSmallestUnit,
                            fromCurrency,
                            toCurrency,
                            fromSmallestUnit: true,
                        });
                        expect(formattedPrice).toBe(expected);
                    });
                });
            });
            describe('when price is in main unit', () => {
                conversionTestCases.forEach(({ description, priceMainUnit, fromCurrency, toCurrency, expected, }) => {
                    it(`should ${description} from main unit`, () => {
                        const formattedPrice = (0, utils_1.priceFormatter)({
                            price: priceMainUnit,
                            fromCurrency,
                            toCurrency,
                        });
                        expect(formattedPrice).toBe(expected);
                    });
                });
            });
        });
    });
});
